%bcond_with docs

Summary:          OpenStack Placement
Name:             openstack-placement
Version:          8.0.0
Release:          3%{?dist}
License:          ASL 2.0
URL:              http://git.openstack.org/cgit/openstack/placement/
Source0:          https://tarballs.openstack.org/placement/%{name}-%{version}.tar.gz
Source1:          placement-dist.conf
Source2:          placement.logrotate
Source3:          placement-api.conf
Source4:          policy.json

BuildRequires:    intltool python3-devel git-core python3-os-traits python3-setuptools python3-pbr
BuildRequires:    python3-six python3-oslo-policy python3-ddt python3-oslo-rootwrap python3-oslo-log
BuildRequires:    python3-oslo-concurrency python3-oslo-config python3-oslo-context python3-oslo-db
BuildRequires:    python3-oslo-middleware python3-oslo-serialization python3-oslo-policy
BuildRequires:    python3-oslo-upgradecheck python3-oslo-utils python3-oslotest python3-osprofiler
BuildRequires:    python3-subunit python3-tooz python3-oslo-vmware python3-cursive python3-os-service-types
BuildRequires:    python3-os-resource-classes python3-microversion-parse python3-jsonschema python3-sqlalchemy
BuildRequires:    python3-routes python3-webob python3-keystonemiddleware python3-requests python3-stestr
BuildRequires:    python3-importlib-metadata
Requires:         openstack-placement-api

BuildArch:        noarch

%description
OpenStack Placement provides an HTTP service for managing,
selecting, and claiming providers of classes of inventory
representing available resources in a cloud.


%package common
Summary:          Components common to all OpenStack Placement services
Requires:         python3-placement = %{version}-%{release}

%description common
OpenStack Placement provides an HTTP service for managing,
selecting, and claiming providers of classes of inventory
representing available resources in a cloud.
This package contains scripts, config and dependencies shared
between all the OpenStack Placement services.

%package api
Summary:          OpenStack Placement API service
Requires:         openstack-placement-common = %{version}-%{release}
Requires:         httpd python3-mod_wsgi

%description api
OpenStack Placement provides an HTTP service for managing,
selecting, and claiming providers of classes of inventory
representing available resources in a cloud.
This package contains the Placement service, which will initially
allow for the management of resource providers.

%package -n       python3-placement
Summary:          Placement Python libraries
Requires:         python3-sqlalchemy python3-routes python3-webob python3-keystonemiddleware python3-jsonschema
Requires:         python3-microversion-parse python3-os-traits python3-os-resource-classes python3-oslo-concurrency
Requires:         python3-oslo-config python3-oslo-context python3-oslo-db python3-oslo-log python3-oslo-middleware
Requires:         python3-oslo-serialization python3-oslo-upgradecheck python3-oslo-utils python3-oslo-policy
Requires:         python3-pbr python3-requests

%description -n   python3-placement
OpenStack Placement provides an HTTP service for managing,
selecting, and claiming providers of classes of inventory
representing available resources in a cloud.
This package contains the Placement Python library.

%package -n python3-placement-tests
Summary:        Placement tests
Requires:       openstack-placement-common = %{version}-%{release}
Requires:       python3-hacking python3-coverage python3-fixtures python3-mock python3-PyMySQL
Requires:       python3-oslotest python3-stestr python3-testtools python3-gabbi python3-wsgi_intercept

%description -n python3-placement-tests
OpenStack Placement provides an HTTP service for managing,
selecting, and claiming providers of classes of inventory
representing available resources in a cloud.
This package contains the Placement Python library tests.

%if %{with docs}
%package doc
Summary:          Documentation for OpenStack Placement
BuildRequires:    graphviz python3-openstackdocstheme python3-oslo-config python3-oslo-log
BuildRequires:    python3-oslo-messaging python3-oslo-utils python3-routes python3-sphinx
BuildRequires:    python3-sphinxcontrib-actdiag python3-sphinxcontrib-seqdiag
BuildRequires:    python3-sphinx-feature-classification python3-sqlalchemy python3-webob

%description      doc
OpenStack Placement provides an HTTP service for managing,
selecting, and claiming providers of classes of inventory
representing available resources in a cloud.
This package contains documentation files for Placement.
%endif

%prep
%autosetup -n openstack-placement-%{version} -S git
find . \( -name .gitignore -o -name .placeholder \) -delete
find placement -name \*.py -exec sed -i '/\/usr\/bin\/env python/{d;q}' {} +
rm -rf *requirements.txt

%build
PYTHONPATH=. oslo-config-generator --config-file=etc/placement/config-generator.conf
PYTHONPATH=. oslopolicy-sample-generator --config-file=etc/placement/policy-generator.conf
%py3_build

%install
%py3_install

%if %{with docs}
export PYTHONPATH=.
sphinx-build -W -b html -d doc/build/doctrees doc/source doc/build/html
rm -rf doc/build/html/.{doctrees,buildinfo}
%endif

install -d -m 750 %{buildroot}%{_localstatedir}/log/placement
install -d -m 755 %{buildroot}%{_sysconfdir}/placement
install -p -D -m 640 etc/placement/placement.conf.sample  %{buildroot}%{_sysconfdir}/placement/placement.conf
install -p -D -m 640 %{SOURCE1} %{buildroot}%{_datarootdir}/placement/placement-dist.conf
install -p -D -m 640 %{SOURCE3} %{buildroot}%{_sysconfdir}/httpd/conf.d/00-placement-api.conf
install -p -D -m 640 %{SOURCE4} %{buildroot}%{_sysconfdir}/placement/policy.json
install -p -D -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/logrotate.d/openstack-placement
install -d -m 755 %{buildroot}%{_datarootdir}/placement
install -p -D -m 755 tools/mysql-migrate-db.sh %{buildroot}%{_datarootdir}/placement/mysql-migrate-db.sh
install -p -D -m 755 tools/postgresql-migrate-db.sh %{buildroot}%{_datarootdir}/placement/postgresql-migrate-db.sh

%check
OS_TEST_PATH=./placement/tests/unit stestr run

%pre common
getent group placement >/dev/null || groupadd -r placement
getent passwd placement >/dev/null || \
    useradd -r -g placement -d / -s /bin/bash -c "OpenStack Placement" placement
exit 0

%files common
%license LICENSE
%doc etc/placement/policy.yaml.sample
%{_bindir}/placement-manage
%{_bindir}/placement-status
%dir %{_datarootdir}/placement
%attr(-, root, placement) %{_datarootdir}/placement/placement-dist.conf
%{_datarootdir}/placement/mysql-migrate-db.sh
%{_datarootdir}/placement/postgresql-migrate-db.sh
%dir %{_sysconfdir}/placement
%config(noreplace) %attr(-, root, placement) %{_sysconfdir}/placement/placement.conf
%config(noreplace) %attr(-, root, placement) %{_sysconfdir}/placement/policy.json
%config(noreplace) %{_sysconfdir}/logrotate.d/openstack-placement
%dir %attr(0750, placement, root) %{_localstatedir}/log/placement

%files api
%license LICENSE
%config(noreplace) %{_sysconfdir}/httpd/conf.d/00-placement-api.conf
%{_bindir}/placement-api

%files -n python3-placement
%license LICENSE
%{python3_sitelib}/placement
%{python3_sitelib}/placement_db_tools
%{python3_sitelib}/openstack_placement-*.egg-info
%exclude %{python3_sitelib}/placement/tests

%files -n python3-placement-tests
%license LICENSE
%{python3_sitelib}/placement/tests

%if %{with docs}
%files doc
%license LICENSE
%doc doc/build/html
%endif

%changelog
* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 8.0.0-3
- Rebuilt for loongarch release

* Sun Oct 8 2023 Shuo Wang <abushwang@tencent.com> - 8.0.0-2
- do not support doc to remove many deprecated packages

* Sat Oct 07 2023 jackeyji <jackeyji@tencent.com> - 8.0.0-1
- upgrade to 8.0.0

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.0.1-4
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.0.1-3
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.0.1-2
- Rebuilt for OpenCloudOS Stream 23.05

* Thu Apr 13 2023 Miaojun Dong <zoedong@tencent.com> - 5.0.1-1
- initial build
